====================
django-codenerix-pos
====================

Codenerix POS is a module that enables `CODENERIX <https://www.codenerix.com/>`_ to set Point Of Services on several platforms in a general manner

.. image:: https://github.com/codenerix/django-codenerix/raw/master/codenerix/static/codenerix/img/codenerix.png
    :target: https://www.codenerix.com
    :alt: Try our demo with Codenerix Cloud

****
Demo
****

Coming soon...

**********
Quickstart
**********

1. Install this package::

    For python 2: sudo pip2 install django-codenerix-pos
    For python 3: sudo pip3 install django-codenerix-pos

2. Add "codenerix_pos" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...
        'codenerix_pos',
    ]

3. Since Codenerix Products is a library, you only need to import its parts into your project and use them.

*************
Documentation
*************

Coming soon... do you help us?

You can get in touch with us `here <https://codenerix.com/contact/>`_.

*******
Credits
*******

Several technologies have been used to build CODENERIX POS:

=================================== =================== =========================== =========================================================
Project name                        License             Owner                       Link to project
=================================== =================== =========================== =========================================================
Reconnecting Websocket              MIT                 Joe Walnes                  https://github.com/joewalnes/reconnecting-websocket
=================================== =================== =========================== =========================================================
